from kivy.app import App
from kivy.graphics import *
from kivy.uix.widget import Widget
from kivy.utils import get_color_from_hex

HEX_SIZE = 100
HORIZONTAL_BUFFER = 0.9
VERTICAL_BUFFER = 0.8


class HexMap(Widget):

    def __init__(self, **kwargs):
        super(HexMap, self).__init__(**kwargs)
        self.redraw_scene()

        # It is crucial to redraw the scene whenever the scene or position changes.
        self.bind(size=self.redraw_scene, pos=self.redraw_scene)

    def redraw_scene(self, *args):
        with self.canvas:
            # Clear scene
            Color(*get_color_from_hex("#000000ff"))
            Rectangle(
                pos=(0, 0),
                size=(self.width, self.height)
            )

            # Draw a hexagon in a decent spot.
            tiles_in_even_row = int(self.width / (HEX_SIZE * HORIZONTAL_BUFFER))
            tiles_in_odd_row = int((self.width - HEX_SIZE / 2) / (HEX_SIZE * HORIZONTAL_BUFFER))
            tiles_in_col = int(self.height / (HEX_SIZE * VERTICAL_BUFFER))

            for y in range(tiles_in_col):

                if y % 2 == 0:
                    hex_color = "#0000dd55"
                    even_row = True
                    tiles_in_row = tiles_in_even_row
                else:
                    hex_color = "#dd000055"
                    even_row = False
                    tiles_in_row = tiles_in_odd_row

                for x in range(tiles_in_row):
                    Color(*get_color_from_hex(hex_color))

                    if even_row:
                        Ellipse(
                            pos=(x * HEX_SIZE * HORIZONTAL_BUFFER, y * HEX_SIZE * VERTICAL_BUFFER),
                            segments=6,
                            size=(HEX_SIZE, HEX_SIZE),
                        )

                    else:
                        Ellipse(
                            pos=((x * HEX_SIZE * HORIZONTAL_BUFFER) + (0.5 * HEX_SIZE * HORIZONTAL_BUFFER),
                                 y * HEX_SIZE * VERTICAL_BUFFER),
                            segments=6,
                            size=(HEX_SIZE, HEX_SIZE),
                        )


class HexMapApp(App):
    pass


if __name__ == '__main__':
    HexMapApp().run()
